Crate forest

Crate forest 

Modules

auth ðŸ”’
beacon ðŸ”’
blocks ðŸ”’
chain ðŸ”’
chain_sync ðŸ”’
cid_collections ðŸ”’
cli ðŸ”’
cli_shared ðŸ”’
daemon ðŸ”’
db ðŸ”’
dev ðŸ”’
documentation ðŸ”’
This is an empty module for documentation purposes.
eth ðŸ”’
f3 ðŸ”’
fil_cns ðŸ”’
genesis ðŸ”’
health ðŸ”’
interpreter ðŸ”’
ipld ðŸ”’
key_management ðŸ”’
libp2p ðŸ”’
libp2p_bitswap ðŸ”’
Another libp2p bitswap(SPEC) implementation in Rust.
lotus_json ðŸ”’
In the Filecoin ecosystem, there are TWO different ways to present a domain object:
message ðŸ”’
message_pool ðŸ”’
metrics ðŸ”’
networks ðŸ”’
prelude ðŸ”’
rpc ðŸ”’
shim ðŸ”’
state_manager ðŸ”’
state_migration ðŸ”’
statediff ðŸ”’
test_utils ðŸ”’
tool ðŸ”’
utils ðŸ”’
wallet ðŸ”’

Macros

def_is_env_truthy
define_system_states
Define type aliases for system actor State types before and after the state migration, namely SystemStateOld and SystemStateNew
for_each_rpc_method
The macro callback will be passed in each type that implements RpcMethod.
from_str_with
impl_system
Implements fn system_migrator, requiring proper system actor State types being defined by define_system_states macro.
impl_verifier
Implements Verifier, requiring proper Manifest types and system actor State types being defined by define_manifests and define_system_states macros respectively.
list_miners_for_state
make_butterfly_policy
Creates a new butterfly policy with the given version. Works for v10 onward.
make_calibnet_policy
Creates a new calibnet policy with the given version.
make_devnet_policy
Creates a new devnet policy with the given version. Works with v10 onward.
make_height
make_mainnet_policy
Creates a new mainnet policy with the given version.
test_snapshots
to_string_with

Structs

Client
Config
KeyStore
KeyStore structure, this contains a set of KeyInfos indexed by address.

Enums

KeyStoreConfig

Constants

ENCRYPTED_KEYSTORE_NAME
FOREST_KEYSTORE_PHRASE_ENV
Environmental variable which holds the KeyStore encryption phrase.
JWT_IDENTIFIER
constant string that is used to identify the JWT secret key in KeyStore
KEYSTORE_NAME

Statics

GLOBAL ðŸ”’

Functions

forest_dev_main
forest_main
forest_tool_main
forest_wallet_main
forestd_main
verify_token
Verify JWT Token and return the allowed permissions from token