Module sync_cmd

Module sync_cmd 

Enums

SyncCommands

Functions

check_snapshot_progress ๐Ÿ”’
Check if the snapshot download is in progress, if wait is true, wait till snapshot download is completed else return after checking once
clear_previous_lines ๐Ÿ”’
handle_initial_snapshot_check ๐Ÿ”’
Checks if a snapshot download is required or in progress when the node is initializing. If a snapshot download is in progress, it waits for completion before starting the sync monitor.
print_sync_report_details ๐Ÿ”’
Writes the sync status report and returns the number of terminal rows it occupies.
tipset_key_to_string ๐Ÿ”’
wait_for_node_to_start_syncing ๐Ÿ”’
Waits for node initialization to complete (start Syncing).