validation_range

Function validation_range 

fn validation_range(
    current: ChainEpoch,
    from: ChainEpoch,
) -> Result<RangeInclusive<ChainEpoch>>
Returns the range of epochs to validate. This includes special handling for negative from values, which are interpreted as offsets from the current epoch.