Module state_cmd

Module state_cmd 

Structs

ComputeCommand
Compute state tree for an epoch
ReplayComputeCommand
Replay state computation with a db snapshot To be used in conjunction with forest-dev state compute.
ReplayValidateCommand
Replay tipset validation with a db snapshot To be used in conjunction with forest-dev state validate.
ValidateCommand
Validate tipset at a certain epoch

Enums

StateCommand
Interact with Filecoin chain state

Functions

disable_tipset_cache 🔒