MessageRead

Trait MessageRead 

pub trait MessageRead {
    // Required methods
    fn from(&self) -> Address;
    fn to(&self) -> Address;
    fn sequence(&self) -> u64;
    fn value(&self) -> TokenAmount;
    fn method_num(&self) -> u64;
    fn params(&self) -> &RawBytes;
    fn gas_limit(&self) -> u64;
    fn required_funds(&self) -> TokenAmount;
    fn gas_fee_cap(&self) -> TokenAmount;
    fn gas_premium(&self) -> TokenAmount;

    // Provided method
    fn effective_gas_premium(&self, base_fee: &TokenAmount) -> TokenAmount { ... }
}
Message interface to make read-only interactions with Signed and unsigned messages in a generic context.

Required Methods

fn from(&self) -> Address

Returns the from address of the message.

fn to(&self) -> Address

Returns the destination address of the message.

fn sequence(&self) -> u64

Returns the message sequence or nonce.

fn value(&self) -> TokenAmount

Returns the amount sent in message.

fn method_num(&self) -> u64

Returns the method number to be called.

fn params(&self) -> &RawBytes

Returns the encoded parameters for the method call.

fn gas_limit(&self) -> u64

Returns the gas limit for the message.

fn required_funds(&self) -> TokenAmount

Returns the required funds for the message.

fn gas_fee_cap(&self) -> TokenAmount

gets gas fee cap for the message.

fn gas_premium(&self) -> TokenAmount

gets gas premium for the message.

Provided Methods

fn effective_gas_premium(&self, base_fee: &TokenAmount) -> TokenAmount

This method returns the effective gas premium claimable by the miner given the supplied base fee. This method is not used anywhere except the Eth API.

Filecoin clamps the gas premium at gas_fee_cap - base_fee, if lower than the specified premium. Returns 0 if gas_fee_cap is less than base_fee.

Implementations on Foreign Types

Source

impl<'a, T: 'a + MessageRead + ?Sized> MessageRead for &'a T

Source

impl<T: MessageRead + ?Sized> MessageRead for Arc<T>

Implementors