Module msgpool

Module msgpool 

Re-exports

pub use events::MpoolSubscriber;
pub use events::MpoolUpdate;

Modules

events ๐Ÿ”’
Event types published by the pending pool.
metrics ๐Ÿ”’
msg_pool ๐Ÿ”’
msg_set ๐Ÿ”’
Per-sender message set.
pending_store ๐Ÿ”’
Pending message storage and event broadcast.
provider ๐Ÿ”’
reorg ๐Ÿ”’
Reorg handling: revert + apply tipsets against the pending pool.
republish ๐Ÿ”’
Tracks which CIDs were already broadcast in the current republish cycle and exposes a trigger to wake the republish task early.
selection
Contains routines for message selection APIs. Whenever a miner is ready to create a block for a tipset, it invokes the select_messages API which selects an appropriate set of messages such that it optimizes miner reward and chain capacity. See https://docs.filecoin.io/mine/lotus/message-pool/#message-selection for more details
utils ๐Ÿ”’

Constants

BASE_FEE_LOWER_BOUND_FACTOR_CONSERVATIVE ๐Ÿ”’
MIN_GAS ๐Ÿ”’
RBF_DENOM ๐Ÿ”’
REPLACE_BY_FEE_RATIO_MIN ๐Ÿ”’