Module msg_pool

Module msg_pool 

Re-exports

pub use super::msg_set::MsgSetLimits;
pub use super::msg_set::StrictnessPolicy;

Structs

Caches ๐Ÿ”’
Caches owned by MessagePool.
MessagePool
This contains all necessary information needed for the message pool. Keeps track of messages to apply, as well as context needed for verifying transactions.
StateNonceCacheKey ๐Ÿ”’

Enums

TrustPolicy ๐Ÿ”’
Trust policy for whether a message is from a trusted or untrusted source. Untrusted sources are subject to stricter limits.

Constants

BLS_SIG_CACHE_SIZE ๐Ÿ”’
KEY_CACHE_SIZE ๐Ÿ”’
MAX_ACTOR_PENDING_MESSAGES ๐Ÿ”’
MAX_MESSAGE_SIZE ๐Ÿ”’
Maximum size of a serialized message in bytes. Anti-DoS measure to keep the pool from ingesting pathologically large messages.
MAX_UNTRUSTED_ACTOR_PENDING_MESSAGES ๐Ÿ”’
SIG_VAL_CACHE_SIZE ๐Ÿ”’
STATE_NONCE_CACHE_SIZE ๐Ÿ”’

Functions

check_base_fee_floor ๐Ÿ”’
Base-Fee floor check.
resolve_to_key ๐Ÿ”’
Resolve an address to its key form, checking the cache first. Non-ID addresses are returned unchanged.
validate_signature ๐Ÿ”’
validate_static ๐Ÿ”’
validate_with_state ๐Ÿ”’
Check the message against the pre-resolved chain state.