pub fn remove(
from: &Address,
pending: &RwLock<HashMap<Address, MsgSet>>,
sequence: u64,
applied: bool,
) -> Result<(), Error>Expand description
Remove a message from pending given the from address and sequence.
The from address should already be resolved to its key form.