Module msg_set

Module msg_set 

Per-sender message set.

MsgSet owns the pending messages for a single sender address and tracks the next sequence expected for the gap-filling / replace-by-fee rules.

Structs

MsgSet
Simple structure that contains a hash-map of messages where k: message nonce, v: a message which corresponds to that nonce.
MsgSetLimits
Per-actor pending-message limits.

Enums

StrictnessPolicy
Strictness policy for pending insertion.

Constants

MAX_NONCE_GAP 🔒
Maximum allowed nonce gap for trusted message inserts under StrictnessPolicy::Strict.