Module provider

Module provider 

Traits

Provider
Provider Trait. This trait will be used by the message pool to interact with some medium in order to do the operations that are listed below that are required for the message pool.
ProviderExt