Functions
- add_
to_ ๐selected_ msgs - compute_
rbf ๐ - Computes the gas premium required to replace an existing message using provided replace-by-fee ratio.
- compute_
rbf_ ๐min_ premium - Computes the minimum gas premium required to replace an existing message
using
REPLACE_BY_FEE_RATIO_MIN. - get_
base_ ๐fee_ lower_ bound - get_
gas_ ๐perf - get_
gas_ ๐reward - Gets the gas reward for the given message.
- recover_
sig ๐ - Attempt to get a signed message that corresponds to an unsigned message in
bls_sig_cache, logging and returningNonewhen the signature is not cached. https://github.com/filecoin-project/lotus/blob/27abf0f16a7f2a83305910f3c2a1844764d20b75/chain/messagepool/messagepool.go#L1564 - recovered_
bls_ ๐messages - Recover the signed forms of a blockโs unsigned BLS messages,
dropping any whose signature is not cached. See
recover_sig. - remove_
from_ ๐selected_ msgs