Module compression_layer

Module compression_layer 

HTTP response compression middleware that normalizes the response body back to jsonrpseeโ€™s HttpBody so the layer can be conditionally installed via tower::util::option_layer.

Ported from reth_rpc_layer::compression_layer.

Structs

CompressionLayer ๐Ÿ”’
Compresses responses with a body above min_body_size bytes.
CompressionService ๐Ÿ”’

Constants

COMPRESS_MIN_BODY_SIZE_VAR ๐Ÿ”’

Statics

COMPRESS_MIN_BODY_SIZE ๐Ÿ”’
RPC response compression policy, read from COMPRESS_MIN_BODY_SIZE_VAR.

Functions

parse_compress_min_body_size ๐Ÿ”’
Interpret a COMPRESS_MIN_BODY_SIZE_VAR value.