Module implementation_defined_errors

Module implementation_defined_errors 

According to the JSON-RPC 2.0 spec, the error codes from -32000 to -32099 are reserved for implementation-defined server-errors. We define them here.

Constants

EXPENSIVE_FORK_CODE 🔒
EIP-1474 “resource unavailable”: explicit call targets a block whose state cannot be served without running an expensive migration on demand.
INSUFFICIENT_PERMISSIONS 🔒
The token authenticated, but its permissions do not allow the requested method. (Token verification failures are rejected earlier with an HTTP 401, not this code.)
UNSUPPORTED_METHOD 🔒
This error indicates that the method is not supported by the current version of the Forest node. Note that it’s not the same as not found, as we are explicitly not supporting it, e.g., because it’s deprecated or Lotus is doing the same.