fn bare_http_response<B: Default>(status: StatusCode) -> Response<B>Expand description
A bare HTTP response carrying just status and an empty body.
fn bare_http_response<B: Default>(status: StatusCode) -> Response<B>A bare HTTP response carrying just status and an empty body.