Enums
Constants
- EXECUTION_
REVERTED_ CODE - This error indicates that the execution reverted while executing the message. Error code 3 was introduced in geth v1.9.15 and is now expected by most Ethereum ecosystem tooling for automatic ABI decoding of revert reasons from the error data field.
- LIMIT_
EXCEEDED_ CODE - This error indicates that the block range provided in the RPC exceeds the configured maximum It was introduced in EIP-1474