pub struct ExitCode(ExitCode);Expand description
Newtype wrapper for the FVM ExitCode.
Examples
let fvm2_success = fvm_shared2::error::ExitCode::new(0);
let fvm3_success = fvm_shared3::error::ExitCode::new(0);
let shim_from_v2 = ExitCode::from(fvm2_success);
let shim_from_v3 = ExitCode::from(fvm3_success);
assert_eq!(shim_from_v2, shim_from_v3);
assert_eq!(shim_from_v2, fvm2_success.into());
assert_eq!(shim_from_v3, fvm3_success.into());Tuple Fields
0: ExitCodeImplementations
Sourceimpl ExitCode
impl ExitCode
Sourcepub const FIRST_USER_EXIT_CODE: u32 = ExitCode_latest::FIRST_USER_EXIT_CODE
pub const FIRST_USER_EXIT_CODE: u32 = ExitCode_latest::FIRST_USER_EXIT_CODE
The lowest exit code that an actor may abort with.
Sourcepub const SYS_OUT_OF_GAS: Self
pub const SYS_OUT_OF_GAS: Self
Message execution (including sub-calls) used more gas than the specified limit.
Sourcepub const SYS_INSUFFICIENT_FUNDS: Self
pub const SYS_INSUFFICIENT_FUNDS: Self
The message sender didnโt have the requisite funds.
Sourcepub const FIRST_ACTOR_ERROR_CODE: u32 = 16
pub const FIRST_ACTOR_ERROR_CODE: u32 = 16
The initial range of exit codes is reserved for system errors. Actors may define codes starting with this one.
pub fn value(&self) -> u32
pub fn is_success(&self) -> bool
pub const fn new(value: ExitCode_latest) -> Self