pub(in state_migration) struct StateMigration<BS> {
migrations: CidHashMap<Arc<dyn ActorMigration<BS> + Send + Sync>>,
verifier: Option<Arc<dyn ActorMigrationVerifier<BS> + Send + Sync>>,
post_migrators: Vec<Arc<dyn PostMigrator<BS>>>,
post_migration_checks: Vec<Arc<dyn PostMigrationCheck<BS>>>,
}Expand description
Handles several cases of migration:
- nil migrations, essentially mapping one Actor to another,
- migrations where state upgrade is required,
- creating new actors that were not present in the prior network version.
Fields
migrations: CidHashMap<Arc<dyn ActorMigration<BS> + Send + Sync>>verifier: Option<Arc<dyn ActorMigrationVerifier<BS> + Send + Sync>>Verifies correctness of the migration specification.
post_migrators: Vec<Arc<dyn PostMigrator<BS>>>Post migrator(s). This may include new actor creation.
post_migration_checks: Vec<Arc<dyn PostMigrationCheck<BS>>>Post migration checks. This is used to verify the correctness of the migration.
Implementations
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub(in state_migration) fn new( verifier: Option<Arc<dyn ActorMigrationVerifier<BS> + Send + Sync>>, ) -> Self
Sourcepub(in state_migration) fn add_migrator(
&mut self,
prior_cid: Cid,
migrator: Arc<dyn ActorMigration<BS> + Send + Sync>,
)
pub(in state_migration) fn add_migrator( &mut self, prior_cid: Cid, migrator: Arc<dyn ActorMigration<BS> + Send + Sync>, )
Inserts a new migrator into the migration specification.
Sourcepub(in state_migration) fn add_post_migrator(
&mut self,
post_migrator: Arc<dyn PostMigrator<BS>>,
)
pub(in state_migration) fn add_post_migrator( &mut self, post_migrator: Arc<dyn PostMigrator<BS>>, )
Inserts a new post migrator into the post migration specification.
Sourcepub(in state_migration) fn add_post_migration_check(
&mut self,
post_migration_check: Arc<dyn PostMigrationCheck<BS>>,
)
pub(in state_migration) fn add_post_migration_check( &mut self, post_migration_check: Arc<dyn PostMigrationCheck<BS>>, )
Inserts a new post migration check into the post migration checks specification.
Sourceimpl<BS: Blockstore + Send + Sync> StateMigration<BS>
impl<BS: Blockstore + Send + Sync> StateMigration<BS>
pub(in state_migration) fn migrate_state_tree( &self, store: &BS, prior_epoch: i64, actors_in: StateTree<BS>, actors_out: StateTree<BS>, ) -> Result<Cid>
Sourceimpl<BS: Blockstore + Send + Sync> StateMigration<BS>
impl<BS: Blockstore + Send + Sync> StateMigration<BS>
pub fn add_nv17_migrations( &mut self, store: &Arc<BS>, actors_in: &mut StateTree<BS>, new_manifest: &BuiltinActorManifest, prior_epoch: i64, chain: NetworkChain, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv21_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, chain_config: &ChainConfig, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv21fix_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv21fix2_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv22_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, chain_config: &ChainConfig, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv22fix_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv23_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, _chain_config: &ChainConfig, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv24_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, chain_config: &ChainConfig, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv25_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv26fix_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv27_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, ) -> Result<()>
Sourceimpl<BS: Blockstore> StateMigration<BS>
impl<BS: Blockstore> StateMigration<BS>
pub fn add_nv28_migrations( &mut self, store: &Arc<BS>, state: &Cid, new_manifest: &BuiltinActorManifest, ) -> Result<()>