Enums
Functions
- check_
snapshot_ ๐progress - Check if the snapshot download is in progress, if wait is true, wait till snapshot download is completed else return after checking once
- clear_
previous_ ๐lines - handle_
initial_ ๐snapshot_ check - Checks if a snapshot download is required or in progress when the node is initializing. If a snapshot download is in progress, it waits for completion before starting the sync monitor.
- print_
sync_ ๐report_ details - Writes the sync status report and returns the number of terminal rows it occupies.
- tipset_
key_ ๐to_ string - wait_
for_ ๐node_ to_ start_ syncing - Waits for node initialization to complete (start
Syncing).