validation_range

Function validation_range 

fn validation_range(current: i64, from: i64) -> Result<RangeInclusive<i64>>
Returns the range of epochs to validate. This includes special handling for negative from values, which are interpreted as offsets from the current epoch.