macro_rules! for_each_rpc_method {
($callback:path) => { ... };
}Expand description
The macro callback will be passed in each type that implements
RpcMethod.
This is a macro because there is no way to abstract the ARITY on that
trait.
All methods should be entered here.