Module msgpool

Module msgpool 

Modules

metrics ๐Ÿ”’
msg_pool ๐Ÿ”’
provider ๐Ÿ”’
selection
Contains routines for message selection APIs. Whenever a miner is ready to create a block for a tipset, it invokes the select_messages API which selects an appropriate set of messages such that it optimizes miner reward and chain capacity. See https://docs.filecoin.io/mine/lotus/message-pool/#message-selection for more details
utils ๐Ÿ”’

Structs

MpoolCtx ๐Ÿ”’

Constants

BASE_FEE_LOWER_BOUND_FACTOR ๐Ÿ”’
BASE_FEE_LOWER_BOUND_FACTOR_CONSERVATIVE ๐Ÿ”’
MIN_GAS ๐Ÿ”’
RBF_DENOM ๐Ÿ”’
RBF_NUM ๐Ÿ”’
REPLACE_BY_FEE_RATIO ๐Ÿ”’
REPUB_MSG_LIMIT ๐Ÿ”’

Functions

add_to_selected_msgs ๐Ÿ”’
This is a helper function for head_change. This method will add a signed message to the given messages selected by priority HashMap.
head_change
Revert and/or apply tipsets to the message pool. This function should be called every time that there is a head change in the message pool.
republish_pending_messages ๐Ÿ”’
select_messages_for_block ๐Ÿ”’
Select messages from the mempool to be included in the next block that builds on a given base tipset. The messages should be eligible for inclusion based on their sequences and the overall number of them should observe block gas limits.