Module msg_pool

Module msg_pool 

Re-exports

pub use super::msg_set::MsgSetLimits;
pub use super::msg_set::StrictnessPolicy;

Structs

MessagePool
This contains all necessary information needed for the message pool. Keeps track of messages to apply, as well as context needed for verifying transactions.
StateNonceCacheKey ๐Ÿ”’

Enums

TrustPolicy
Trust policy for whether a message is from a trusted or untrusted source. Untrusted sources are subject to stricter limits.

Constants

BLS_SIG_CACHE_SIZE ๐Ÿ”’
KEY_CACHE_SIZE ๐Ÿ”’
MAX_ACTOR_PENDING_MESSAGES
MAX_MESSAGE_SIZE ๐Ÿ”’
Maximum size of a serialized message in bytes. This is an anti-DOS measure to prevent large messages from being added to the message pool.
MAX_UNTRUSTED_ACTOR_PENDING_MESSAGES
SIG_VAL_CACHE_SIZE ๐Ÿ”’
STATE_NONCE_CACHE_SIZE ๐Ÿ”’

Functions

add_helper ๐Ÿ”’
Finish verifying the signed message before adding it to the pending mset hash-map. If an entry in the hash-map does not yet exist, create a new mset that will correspond to the form message and push it to the pending hash-map.
get_state_sequence ๐Ÿ”’
Get the state nonce for an address, accounting for messages already included in cur_ts.
resolve_to_key ๐Ÿ”’
Resolve an address to its key form, checking the cache first. Non-ID addresses are returned unchanged.
verify_msg_before_add ๐Ÿ”’