Re-exports
pub use super::msg_set::MsgSetLimits;pub use super::msg_set::StrictnessPolicy;
Structs
- Message
Pool - This contains all necessary information needed for the message pool. Keeps track of messages to apply, as well as context needed for verifying transactions.
- State
Nonce ๐Cache Key
Enums
- Trust
Policy - Trust policy for whether a message is from a trusted or untrusted source. Untrusted sources are subject to stricter limits.
Constants
- BLS_
SIG_ ๐CACHE_ SIZE - KEY_
CACHE_ ๐SIZE - MAX_
ACTOR_ PENDING_ MESSAGES - MAX_
MESSAGE_ ๐SIZE - Maximum size of a serialized message in bytes. This is an anti-DOS measure to prevent large messages from being added to the message pool.
- MAX_
UNTRUSTED_ ACTOR_ PENDING_ MESSAGES - SIG_
VAL_ ๐CACHE_ SIZE - STATE_
NONCE_ ๐CACHE_ SIZE
Functions
- add_
helper ๐ - Finish verifying the signed message before adding it to the pending
msethash-map. If an entry in the hash-map does not yet exist, create a newmsetthat will correspond to the form message and push it to the pending hash-map. - get_
state_ ๐sequence - Get the state nonce for an address, accounting for messages already included in
cur_ts. - resolve_
to_ ๐key - Resolve an address to its key form, checking the cache first. Non-ID addresses are returned unchanged.
- verify_
msg_ ๐before_ add