Module utils

Module utils 

Functions

add_to_selected_msgs ๐Ÿ”’
compute_rbf ๐Ÿ”’
Computes the gas premium required to replace an existing message using provided replace-by-fee ratio.
compute_rbf_min_premium ๐Ÿ”’
Computes the minimum gas premium required to replace an existing message using REPLACE_BY_FEE_RATIO_MIN.
get_base_fee_lower_bound ๐Ÿ”’
get_gas_perf ๐Ÿ”’
get_gas_reward ๐Ÿ”’
Gets the gas reward for the given message.
recover_sig ๐Ÿ”’
Attempt to get a signed message that corresponds to an unsigned message in bls_sig_cache, logging and returning None when the signature is not cached. https://github.com/filecoin-project/lotus/blob/27abf0f16a7f2a83305910f3c2a1844764d20b75/chain/messagepool/messagepool.go#L1564
recovered_bls_messages ๐Ÿ”’
Recover the signed forms of a blockโ€™s unsigned BLS messages, dropping any whose signature is not cached. See recover_sig.
remove_from_selected_msgs ๐Ÿ”’