Module utils

Module utils 

Functions

add_to_selected_msgs ๐Ÿ”’
compute_rbf ๐Ÿ”’
Computes the gas premium required to replace an existing message using provided replace-by-fee ratio.
compute_rbf_min_premium ๐Ÿ”’
Computes the minimum gas premium required to replace an existing message using REPLACE_BY_FEE_RATIO_MIN.
get_base_fee_lower_bound ๐Ÿ”’
get_gas_perf ๐Ÿ”’
get_gas_reward ๐Ÿ”’
Gets the gas reward for the given message.
recover_sig ๐Ÿ”’
Attempt to get a signed message that corresponds to an unsigned message in bls_sig_cache.
remove_from_selected_msgs ๐Ÿ”’