Functions
- add_
to_ ๐selected_ msgs - compute_
rbf ๐ - Computes the gas premium required to replace an existing message using provided replace-by-fee ratio.
- compute_
rbf_ ๐min_ premium - Computes the minimum gas premium required to replace an existing message
using
REPLACE_BY_FEE_RATIO_MIN. - get_
base_ ๐fee_ lower_ bound - get_
gas_ ๐perf - get_
gas_ ๐reward - Gets the gas reward for the given message.
- recover_
sig ๐ - Attempt to get a signed message that corresponds to an unsigned message in
bls_sig_cache. - remove_
from_ ๐selected_ msgs